package com.spiffymap.naviupdate.model;

import java.util.ArrayList;
import java.util.Objects;
import java.util.List;

/**
 *
 * @author steve
 */
public class CellData implements Comparable<CellData>, Named {

    private final String repositoryName;
    private final String cellName;
    private final List<CellDataDirectory> cellDataDirectories = new ArrayList<>();

    public CellData(String repositoryName, String cellName) {
        this.repositoryName = repositoryName;
        this.cellName = cellName;
    }

    /**
     * Comparable implementation
     *
     * @param other
     * @return -1,0, or 1
     */
    @Override
    public int compareTo(CellData other) {
        return cellName.compareTo(other.getName());
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 67 * hash + Objects.hashCode(this.cellName);
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final CellData other = (CellData) obj;
        if (!Objects.equals(this.cellName, other.cellName)) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "CellData{" + "cellName=" + cellName + ", cellDataDirectories=" + cellDataDirectories + '}';
    }

    /**
     * @return the cellName
     */
    @Override
    public String getName() {
        return cellName;
    }

    /**
     * @return the cellDataDirectories
     */
    public List<CellDataDirectory> getCellDataDirectories() {
        return cellDataDirectories;
    }

    /**
     * @return the repositoryName
     */
    public String getRepositoryName() {
        return repositoryName;
    }

    /**
     * @return the cellName
     */
    public String getCellName() {
        return cellName;
    }

}
