package com.spiffymap.naviupdate.model;

import java.util.ArrayList;
import java.util.Objects;
import java.util.List;

/**
 * This represents a directory with data in about a cell, such as a base cell or
 * update, text and image files.
 *
 * @version 25-May-2017
 * @author steve
 */
public class CellDataDirectory implements Comparable<CellDataDirectory>, Named {

    private final String repositoryName;
    private final String cellName;
    // Path to directory within repository, using Unix path separators
    private final String relativePath;
    // Cell edition
    private final int edition;
    // Update number
    private final int updateNumber;
    private final List<FileData> cellFiles = new ArrayList<>();
    private final List<FileData> signatureFiles = new ArrayList<>();
    private final List<FileData> otherFiles = new ArrayList<>();

    public CellDataDirectory(String repositoryName, String cellName, String relativePath, int edition, int updateNumber) {
        this.repositoryName = repositoryName;
        this.cellName = cellName;
        this.relativePath = relativePath;
        this.edition = edition;
        this.updateNumber = updateNumber;
    }

    /**
     * Comparable implementation
     *
     * @param other
     * @return -1,0, or 1
     */
    @Override
    public int compareTo(CellDataDirectory other) {
        return relativePath.compareTo(other.getRelativePath());
    }

    @Override
    public int hashCode() {
        int hash = 3;
        hash = 11 * hash + Objects.hashCode(this.relativePath);
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final CellDataDirectory other = (CellDataDirectory) obj;
        if (!Objects.equals(this.relativePath, other.relativePath)) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "CellDataDirectory{" + "relativePath=" + relativePath + '}';
    }

    /**
     * @return the relativePath
     */
    public String getRelativePath() {
        return relativePath;
    }

    /**
     * Relative path is used as the name
     *
     * @return relative path
     */
    @Override
    public String getName() {
        return relativePath;
    }

    /**
     * @return the cellFiles
     */
    public List<FileData> getCellFiles() {
        return cellFiles;
    }

    /**
     * @return the signatureFiles
     */
    public List<FileData> getSignatureFiles() {
        return signatureFiles;
    }

    /**
     * @return the otherFiles
     */
    public List<FileData> getOtherFiles() {
        return otherFiles;
    }

    /**
     * @return the edition
     */
    public int getEdition() {
        return edition;
    }

    /**
     * @return the updateNumber
     */
    public int getUpdateNumber() {
        return updateNumber;
    }

    /**
     * @return the repositoryName
     */
    public String getRepositoryName() {
        return repositoryName;
    }

    /**
     * @return the cellName
     */
    public String getCellName() {
        return cellName;
    }
}
