package com.spiffymap.naviupdate.model;

import com.spiffymap.util.shared.compressed.CompressedString;
import java.util.Arrays;
import java.util.Objects;

public class CompressedLinkedString implements Comparable<CompressedLinkedString> {

    private final byte[] contents;
    private final CompressedLinkedString link;

    public CompressedLinkedString(String contents) {
        this.contents = new CompressedString(contents).getBytes();
        link = null;
    }

    public CompressedLinkedString(String contents, CompressedLinkedString link) {
        this.contents = new CompressedString(contents).getBytes();
        this.link = link;
    }

    public String getString() {
        String linkedString = "";
        if (link != null) {
            linkedString = link.getString();
        }
        return linkedString + new CompressedString(contents).toString();
    }

    @Override
    public int compareTo(CompressedLinkedString other) {
        return getString().compareTo(other.getString());
    }

    @Override
    public int hashCode() {
        int hash = 5;
        hash = 79 * hash + Arrays.hashCode(this.contents);
        hash = 79 * hash + Objects.hashCode(this.link);
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final CompressedLinkedString other = (CompressedLinkedString) obj;
        if (!Arrays.equals(this.contents, other.contents)) {
            return false;
        }
        if (!Objects.equals(this.link, other.link)) {
            return false;
        }
        return true;
    }
   
}
