package com.spiffymap.naviupdate.model;

import com.spiffymap.util.server.FileUtils;
import java.io.Serializable;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Objects;

/**
 *
 * @author steve
 */
public abstract class Entry implements Comparable<Entry>, Serializable {

    private String comparisonString;

    private static final long serialVersionUID = -919925724687800248L;

    private String name;
    // Parent can be either a Directory or a FileTree
    private Object parent;

    public Entry() {
    }

    public Entry(String name, Object parent) {
        this.name = name;
        this.parent = parent;
    }

    public String getComparisonString() {
        if (comparisonString == null) {
            comparisonString = workOutComparisonString();
        }
        return comparisonString;
    }

    protected String workOutComparisonString() {
        return FileUtils.getComparisonString(getRelativePath());
    }

    /**
     * Return the path to this entry relative to the repository origin.
     *
     * @return relative path
     */
    public Path getRelativePath() {
        if (parent == null && !(parent instanceof Directory)) {
            return Paths.get(name);
        } else {
            return ((Directory) parent).getRelativePath().resolve(name);
        }
    }

    /**
     * Return a path string version of 'getRelativePath()' but lower case and
     * with UNIX separators.
     *
     * @return UNIX-style path string
     */
    public String getUnixStyleRelativePathString() {
        return getRelativePath().toString().toLowerCase().replace('\\', '/');
    }

    /**
     * @param name the name to set
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * @param parent the parent to set
     */
    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     *
     * @param other
     * @return -1,0, or 1
     */
    @Override
    public int compareTo(Entry other) {
        return getComparisonString().compareTo(other.getComparisonString());
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 41 * hash + Objects.hashCode(getComparisonString());
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Entry other = (Entry) obj;
        if (!Objects.equals(getComparisonString(), other.getComparisonString())) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "Entry{" + "name=" + name + '}';
    }

    /**
     * @return the name
     */
    public String getName() {
        return name;
    }

    /**
     * @return the parent
     */
    public Object getParent() {
        return parent;
    }
}
