package com.spiffymap.naviupdate.model;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.Objects;
import org.springframework.util.FileCopyUtils;

/**
 * Information about a file, such as hash.
 *
 * @version 26-May-2017
 * @author steve
 */
public class FileData implements Comparable<FileData>, Named {

    private final String name;
    private final byte[] hash;

    private final static MessageDigest fileDigest;

    static {
        try {
            fileDigest = MessageDigest.getInstance("MD5");
        } catch (NoSuchAlgorithmException nsae) {
            // Should never happen - throw as runtime exception
            throw new RuntimeException(nsae);
        }
    }

    /**
     * Calculate the hash for a file
     *
     * @param fileName
     * @return hash
     * @throws IOException
     */
    public static byte[] calculateHash(String fileName) throws IOException {
        synchronized (fileDigest) {
            fileDigest.reset();
            try (InputStream in = new FileInputStream(fileName)) {
                byte[] buffer = FileCopyUtils.copyToByteArray(in);
                return fileDigest.digest(buffer);
            }
        }
    }

    /**
     *
     * @param name
     * @param hash
     */
    public FileData(String name, byte[] hash) {
        this.name = name;
        this.hash = hash;
    }

    /**
     * Comparable implementation
     *
     * @param other
     * @return -1,0, or 1
     */
    @Override
    public int compareTo(FileData other) {
        return name.compareTo(other.getName());
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 53 * hash + Objects.hashCode(this.name);
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final FileData other = (FileData) obj;
        if (!Objects.equals(this.name, other.name)) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "FileData{" + "name=" + name + ", hash=" + hash + '}';
    }

    /**
     * @return the name
     */
    @Override
    public String getName() {
        return name;
    }

    /**
     * @return the hash
     */
    public byte[] getHash() {
        return hash;
    }

}
