package com.spiffymap.naviupdate.model;

import com.spiffymap.util.shared.date.DayTimeStamp;
import java.util.Map;
import java.util.Set;
import java.util.HashMap;

/**
 * Represents file requests needed to update a repository. 02-Jun-2017
 *
 * @author steve
 */
public class FileRequests {

    private final String repositoryName;
    private final String created;
    private String lastProcessed;
    private String completed;
    private final Set<FileMetaDataEntry> filesToAdd;
    private final Set<FileMetaDataEntry> filesToUpdate;
    private final Set<FileMetaDataEntry> filesToDelete;
    // Maps of file to String representation of date
    private final Map<FileMetaDataEntry, String> filesAdded = new HashMap<>();
    private final Map<FileMetaDataEntry, String> filesUpdated = new HashMap<>();
    private final Map<FileMetaDataEntry, String> filesDeleted = new HashMap<>();

    /**
     *
     * @param repositoryName
     * @param created
     * @param filesToAdd
     * @param filesToUpdate
     * @param filesToDelete
     */
    public FileRequests(String repositoryName, DayTimeStamp created, Set<FileMetaDataEntry> filesToAdd, Set<FileMetaDataEntry> filesToUpdate,
            Set<FileMetaDataEntry> filesToDelete) {
        this.repositoryName = repositoryName;
        this.created = created.toString();
        this.filesToAdd = filesToAdd;
        this.filesToUpdate = filesToUpdate;
        this.filesToDelete = filesToDelete;
    }

    /**
     * @return the repositoryName
     */
    public String getRepositoryName() {
        return repositoryName;
    }

    /**
     * @return the created
     */
    public DayTimeStamp getCreated() {
        return DayTimeStamp.fromString(created);
    }

    /**
     * @return the lastProcessed
     */
    public DayTimeStamp getLastProcessed() {
        return DayTimeStamp.fromString(lastProcessed);
    }

    /**
     * @param lastProcessed the lastProcessed to set
     */
    public void setLastProcessed(DayTimeStamp lastProcessed) {
        this.lastProcessed = lastProcessed.toString();
    }

    /**
     * @return the completed
     */
    public DayTimeStamp getCompleted() {
        return DayTimeStamp.fromString(completed);
    }

    /**
     * @param completed the completed to set
     */
    public void setCompleted(DayTimeStamp completed) {
        this.completed = completed.toString();
    }

    /**
     * @return the filesToAdd
     */
    public Set<FileMetaDataEntry> getFilesToAdd() {
        return filesToAdd;
    }

    /**
     * @return the filesToUpdate
     */
    public Set<FileMetaDataEntry> getFilesToUpdate() {
        return filesToUpdate;
    }

    /**
     * @return the filesToDelete
     */
    public Set<FileMetaDataEntry> getFilesToDelete() {
        return filesToDelete;
    }

    /**
     * @return the filesAdded
     */
    public Map<FileMetaDataEntry, String> getFilesAdded() {
        return filesAdded;
    }

    /**
     * @return the filesUpdated
     */
    public Map<FileMetaDataEntry, String> getFilesUpdated() {
        return filesUpdated;
    }

    /**
     * @return the filesDeleted
     */
    public Map<FileMetaDataEntry, String> getFilesDeleted() {
        return filesDeleted;
    }

}
