package com.spiffymap.naviupdate.model;

import java.util.Objects;

/**
 * Combination of data from Update and Entry
 *
 * @author steve
 */
public class SimpleUpdateData implements Comparable<SimpleUpdateData> {

    private final String path;
    private final boolean directory;
    private final UpdateType type;
    
    public SimpleUpdateData(Update update) {
        this(update.getEntry(),update.getUpdateType());
    }

    public SimpleUpdateData(Entry entry, UpdateType type) {
        path = entry.getRelativePath().toString();
        directory = entry instanceof Directory;
        this.type = type;
    }
    
    @Override
    public int compareTo(SimpleUpdateData other) {
        return (path + type).compareTo(other.getPath() + other.getType());
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 53 * hash + Objects.hashCode(this.path);
        hash = 53 * hash + (this.directory ? 1 : 0);
        hash = 53 * hash + Objects.hashCode(this.type);
        return hash;
    }
    
    

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final SimpleUpdateData other = (SimpleUpdateData) obj;
        if (this.directory != other.directory) {
            return false;
        }
        if (!Objects.equals(this.path, other.path)) {
            return false;
        }
        if (this.type != other.type) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "SimpleUpdateData{" + "path=" + path + ", directory=" + directory + ", type=" + type + '}';
    }

    /**
     * @return the path
     */
    public String getPath() {
        return path;
    }

    /**
     * @return the directory
     */
    public boolean isDirectory() {
        return directory;
    }

    /**
     * @return the type
     */
    public UpdateType getType() {
        return type;
    }
}
