package com.spiffymap.naviupdate.model;

import java.util.ArrayList;
import java.util.Objects;
import java.util.List;

/**
 *
 * @author steve
 */
public class Supplier implements Comparable<Supplier>, Named {

    private String repositoryName;
    private String name;
    private Directory directory;
    private List<CellData> cellData;

    public Supplier() {
        
    }
    
    public Supplier(String repositoryName, String name, Directory directory) {
        if (repositoryName == null) {
            throw new IllegalArgumentException("Repository name must not be null.");
        }
        this.repositoryName = repositoryName;
        if (name == null) {
            throw new IllegalArgumentException("Name must not be null.");
        }
        this.name = name;
        this.directory = directory;
    }

    @Override
    public String toString() {
        return "Supplier{" + "repository name=" + repositoryName+ ",name=" + getName() + '}';
    }

    @Override
    public int compareTo(Supplier other) {
        String otherName = other.getName();
        if (getName() == null || otherName == null) {
            throw new IllegalArgumentException("A name is null");
        }
        return getName().compareTo(otherName);
    }


    public void addCellData(CellData data) {
        if (cellData == null) {
            cellData = new ArrayList<>();
            cellData.add(data);
        }
    }

    /**
     * @return the cellData
     */
    public List<CellData> getCellData() {
        if (cellData == null) {
            cellData = new ArrayList<>();
        }
        return cellData;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 43 * hash + Objects.hashCode(this.repositoryName);
        hash = 43 * hash + Objects.hashCode(this.name);
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Supplier other = (Supplier) obj;
        if (!Objects.equals(this.repositoryName, other.repositoryName)) {
            return false;
        }
        if (!Objects.equals(this.name, other.name)) {
            return false;
        }
        return true;
    }

    /**
     * @return the name
     */
    @Override
    public String getName() {
        return name;
    }

    /**
     * @return the directory
     */
    public Directory getDirectory() {
        return directory;
    }

    /**
     * @param name the name to set
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * @return the repositoryName
     */
    public String getRepositoryName() {
        return repositoryName;
    }

}
