package com.spiffymap.naviupdate.model;

import java.util.Objects;

public class Update implements Comparable<Update> {

    private final String repositoryName;
    private final UpdateType updateType;
    private final Entry entry;

    public Update(String repositoryName, Entry entry, UpdateType updateType) {
        this.repositoryName = repositoryName;
        this.entry = entry;
        this.updateType = updateType;
    }

    public Update copy() {
        return new Update(repositoryName, entry, updateType);
    }

    @Override
    public int compareTo(Update other) {
        return entry.compareTo(other.getEntry());
    }

    @Override
    public int hashCode() {
        int hash = 5;
        hash = 97 * hash + Objects.hashCode(this.repositoryName);
        hash = 97 * hash + Objects.hashCode(this.updateType);
        hash = 97 * hash + Objects.hashCode(this.entry);
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Update other = (Update) obj;
        if (!Objects.equals(this.repositoryName, other.repositoryName)) {
            return false;
        }
        if (this.updateType != other.updateType) {
            return false;
        }
        if (!Objects.equals(this.entry, other.entry)) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "Update{" + "repositoryName=" + repositoryName + ", updateType=" + updateType + ", entry=" + entry + '}';
    }

    /**
     * @return the updateType
     */
    public UpdateType getUpdateType() {
        return updateType;
    }

    /**
     * @return the entry
     */
    public Entry getEntry() {
        return entry;
    }

    /**
     * @return the repositoryName
     */
    public String getRepositoryName() {
        return repositoryName;
    }

}
